@@ -32,12 +32,22 @@ hergm.wrapper <- function(seed, hergm_list)
     as.integer(hergm_list$structural),
     as.integer(hergm_list$min_size),
     as.integer(hergm_list$max_number),
+    as.integer(hergm_list$null$alpha_shape),
+    as.integer(hergm_list$null$alpha_rate),
+    as.integer(hergm_list$null$alpha),
+    as.integer(hergm_list$null$eta_mean_mean),
+    as.integer(hergm_list$null$eta_mean_precision),
+    as.integer(hergm_list$null$eta_precision_shape),
+    as.integer(hergm_list$null$eta_precision_rate),
+    as.integer(hergm_list$null$eta_mean),
+    as.integer(hergm_list$null$eta_precision),
+    as.integer(hergm_list$null$eta),
+    as.integer(hergm_list$null$indicator),
     as.double(hergm_list$alpha),
     as.double(hergm_list$alpha_shape),
     as.double(hergm_list$alpha_rate),
     as.double(hergm_list$eta_mean1),
     as.double(hergm_list$eta_mean2),
-    as.double(hergm_list$b),
     as.double(hergm_list$cf1),
     as.double(hergm_list$cf2),
     as.double(hergm_list$p1),
@@ -94,7 +104,6 @@ hergm.wrapper <- function(seed, hergm_list)
     as.double(hergm_list$alpha_rate),
     as.double(hergm_list$eta_mean1),
     as.double(hergm_list$eta_mean2),
-    as.double(hergm_list$b),
     as.double(hergm_list$cf1),
     as.double(hergm_list$cf2),
     as.double(hergm_list$p1),
